summaryrefslogtreecommitdiffstats
path: root/kverbos/kverbos/kverbosdoc.h
diff options
context:
space:
mode:
Diffstat (limited to 'kverbos/kverbos/kverbosdoc.h')
-rw-r--r--kverbos/kverbos/kverbosdoc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kverbos/kverbos/kverbosdoc.h b/kverbos/kverbos/kverbosdoc.h
index b80eb15b..41dbc2c4 100644
--- a/kverbos/kverbos/kverbosdoc.h
+++ b/kverbos/kverbos/kverbosdoc.h
@@ -114,10 +114,10 @@ class KVerbosDoc : public TQObject
const KURL& URL() const;
/** sets the URL of the document */
void setURL(const KURL& url);
/** es wird ein Verb der Liste hinzugefügt, ist emitStatus = true, wird auch
* die Statuszeile entsprechend angepasst.
*/
- void appendVerb(const verbSpanish v, bool emitStatus = true);
+ void appendVerb(const verbSpanish v, bool emittqStatus = true);
/** prüft, ob die Liste des Dokumentes leer ist */
bool isEmpty() const;
/** Gibt einen Zeiger auf die Verbliste des Dokumentes zurück */
@@ -141,7 +141,7 @@ class KVerbosDoc : public TQObject
public slots:
/**
- * calls repaint() on all views connected to the document object and is called by the view by which the document has been changed.
+ * calls tqrepaint() on all views connected to the document object and is called by the view by which the document has been changed.
* As this view normally repaints itself, it is excluded from the paintEvent.
*/
void slotUpdateAllViews(KVerbosView *sender);
@@ -114,10 +114,10 @@ class KVerbosDoc : public TQObject
/** sets the URL of the document */
void setURL(const KURL& url);
- /** es wird ein Verb der Liste hinzugefügt, ist emitStatus = true, wird auch
+ /** es wird ein Verb der Liste hinzugefügt, ist emittqStatus = true, wird auch
* die Statuszeile entsprechend angepasst.
*/